#
# spec file for package tkimg
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tkimg
Version:        1.4.14
Release:        bp156.1.4
Summary:        More Image Formats for Tk
Group:          Development/Libraries/Tcl
License:        BSD-3-Clause
URL:            https://sourceforge.net/projects/tkimg
Source0:        https://sourceforge.net/projects/tkimg/files/tkimg/1.4/tkimg%%20%{version}/Img-%{version}-Source.tar.gz
Patch0:         tests-add-destdir-tcllibpath.patch
BuildRequires:  dos2unix
BuildRequires:  tcllib
BuildRequires:  tk-devel
BuildRequires:  xvfb-run
BuildRequires:  pkgconfig(x11)

%description
This package contains a collection of image format handlers for the Tk
photo image type, and a new image type, pixmaps.

The provided format handlers include bmp, gif, ico, jpeg, pcx, png,
ppm, ps, sgi, sun, tga, tiff, xbm, and xpm.

%package devel
Summary:        Header Files and C API Documentation for tkimg
Group:          Development/Libraries/Tcl

%description devel
Files needed to compile/link C code against tkimg.

%prep
%autosetup -p1 -n Img-%{version}-Source
# Source archive is likly created on Windows, so fix some issues
# 1. Fix file permissions: Executable bit is set on every file, fix that
find . -type f -not -name configure -exec chmod 0644 \{\} +
# 2. Fix line ending
dos2unix ANNOUNCE ChangeLog README Reorganization.Notes.txt changes doc/*.htm demo.tcl license.terms base/pkgIndex.tcl.in

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
%configure \
        --libdir=%tcl_archdir \
        --with-tcl=%_libdir \
        --with-tk=%_libdir
%make_build

%install
%make_install INSTALL_ROOT=%buildroot
# Fix file permissions
chmod a-x %buildroot%tcl_archdir/*/*.a

%check
xvfb-run make test DESTDIR=%buildroot

%files
%doc ANNOUNCE ChangeLog README Reorganization.Notes.txt changes doc/*.htm demo.tcl
%license license.terms
%doc %_mandir/*/*
%tcl_archdir/*
%exclude %tcl_archdir/*/*.a

%files devel
%_includedir/*
%tcl_archdir/*/*.a

%changelog
* Fri Jun 30 2023 Reinhard Max <max@suse.com>
- Update to version 1.4.14
  * Added support for reading RAW images with 32-bit integer and
    64-bit double pixel values.
  * Fixed compilation of libpng for ARM Neon.
    Obsoletes fix-aarch64-neon.patch .
  * Updated external libraries: JPEG 9e, PNG 1.6.38, TIFF 4.4.0,
    ZLIB 1.2.13.
* Wed Apr 26 2023 Jan Engelhardt <jengelh@inai.de>
- Replace BuildRequire on xorg-x11-devel by pkgconfig(...)
* Fri May 20 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.4.13
  * Disable support of zstd in libtiff
  * Corrected bug in BMP and XBM parser.
  * Bug fix when reading 16-bit images (tkimg_RemapUShortValues).
  * Added new format "flir" for reading FLIR infrared images.
  * Bug fix for reading animated GIF's.
  * Bug fix for RAW format handler regarding AutomaticGainControl.
  * Bug fix for SGI format handler.
  * Enhanced RAW format handler with AutomaticGainControl algorithmn.
  * Fixed Tk panic on exit when pixmap images have been created.
  * Changed behaviour of gamma handling:
    Read: If no gamma is stored in PNG file, no gamma is set.
    Previous behaviour was to set it to 0.45.
    Write: No gamma value is written to PNG file.
    Previous behaviour was to set it to 1.0.
  * Added 2 new PNG format options "-verbose" and "-gamma".
  * Disable jbig support, as this generally cannot be relied upon
  * Bug fix when writing GIF images.
  * Bug fix when reading greyscale PNG images with alpha channel.
  * Added format option "-alpha" to PNG reader to be compatible with Tk 8.6.
  * Bug fixes in various parsers to avoid core dumps when specifying a
    wrong format option.
- Add tests-add-destdir-tcllibpath.patch
  * Add DESTDIR to TCLLIBPATH, so freshly installed tcl packages
    are found if not installing into root.
- Add fix-aarch64-neon.patch
  * Fix build on armv8, disable NEON intrinsics as the required
    source files are not included for libpng
* Mon Jul  1 2019 Martin Liška <mliska@suse.cz>
- Use FAT LTO objects in order to provide proper static
  library (boo#1138797).
* Tue Jul 16 2013 max@suse.com
- Update to version 1.4:
  * obsoletes all patches we've had so far.
- Spec file cleanup
- Split off a devel package
* Wed Sep 26 2012 max@suse.com
- Add libjpeg-devel to BuildRequires to fix the build of img::jpeg
  (bnc#780670).
* Tue Dec 20 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Wed May 21 2008 max@suse.de
- Fix a crash with malformed GIF images (bnc#386009, CVE-2008-0553)
* Mon Feb 20 2006 max@suse.de
- Fixed some serious warnings (#152208).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 max@suse.de
- Disabled parallel make.
* Tue Dec 13 2005 max@suse.de
- Fixed a typo in tcl.m4 that broke configure with bash 3.1.
* Wed Jul 27 2005 max@suse.de
- Moved shared libs to libdir and script library to /usr/share/tcl.
* Wed Jul  6 2005 max@suse.de
- Added missing includes to allow lightweight buffer overflow
  checking.
* Thu Jun  2 2005 ro@suse.de
- try to fix makefile deps
* Wed Apr 27 2005 max@suse.de
- Update to the final 1.3 version.
* Thu Nov 11 2004 ro@suse.de
- fixed file list
* Wed Jul 28 2004 max@suse.de
- Added tkimg-syslibs.patch to use the system-supplied versions of
  libtiff, libjpeg, and libpng (Bug #43008).
* Mon Mar  1 2004 max@suse.de
- New package: tkimg-1.3rc2
- An image format extension for Tk.
